#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "session_null.h"

#include "ext/session/php_session.h"

//#define DEBUG
#undef DEBUG

#ifdef DEBUG
#define	_D(args...) { fprintf(stderr, "%s:%d %s(): ", strrchr(__FILE__, '/') ? strrchr(__FILE__, '/') + 1 : __FILE__, __LINE__, __FUNCTION__); fprintf(stderr, args); fprintf(stderr, "\n"); fflush(stderr); }
#else
#define _D(args...)
#endif

PHP_MINIT_FUNCTION(session_null);
PHP_MSHUTDOWN_FUNCTION(session_null);
PHP_RINIT_FUNCTION(session_null);
PHP_RSHUTDOWN_FUNCTION(session_null);
PHP_MINFO_FUNCTION(session_null);

/* {{{ session_null_module_entry
 */
/* compiled module information */
zend_module_entry session_null_module_entry =
{
#if ZEND_MODULE_API_NO >= 20010901
    STANDARD_MODULE_HEADER,
#endif
	"session_null",
	NULL,
	PHP_MINIT(session_null),
	PHP_MSHUTDOWN(session_null),
	PHP_RINIT(session_null),
	PHP_RSHUTDOWN(session_null),
	PHP_MINFO(session_null),
#if ZEND_MODULE_API_NO >= 20010901
	PHP_SESSION_NULL_VERSION,
#endif
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

/* implement standard "stub" routine to introduce ourselves to Zend */
#if COMPILE_DL_SESSION_NULL
ZEND_GET_MODULE(session_null)
#endif

/* {{{ PHP_MINIT_FUNCTION
 */
PHP_MINIT_FUNCTION(session_null)
{
	php_session_register_module(&ps_mod_null);
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MSHUTDOWN_FUNCTION
 */
PHP_MSHUTDOWN_FUNCTION(session_null)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_RINIT_FUNCTION
 */
PHP_RINIT_FUNCTION(session_null)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_RSHUTDOWN_FUNCTION
 */
PHP_RSHUTDOWN_FUNCTION(session_null)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION
 */
PHP_MINFO_FUNCTION(session_null)
{
	php_info_print_table_start();
	php_info_print_table_row(2, "Null Session Save Handler", "enabled");
	php_info_print_table_row(2, "Version", PHP_SESSION_NULL_VERSION);
	php_info_print_table_end();
}
/* }}} */

ps_module ps_mod_null = {
	PS_MOD(null)
};

/* session save handler functions */
/* {{{ PS_OPEN_FUNC
 */
PS_OPEN_FUNC(null)
{
	// set to non-NULL so session engine won't complain
	PS_SET_MOD_DATA("");

	return SUCCESS;
}
/* }}} */

/* {{{ PS_CLOSE_FUNC
 */
PS_CLOSE_FUNC(null)
{
	// clear session data
	PS_SET_MOD_DATA(NULL);

	return SUCCESS;
}
/* }}} */

/* {{{ PS_READ_FUNC
 */
PS_READ_FUNC(null)
{
	// always return empty session
	*val = STR_EMPTY_ALLOC();

	return SUCCESS;
}
/* }}} */

/* {{{ PS_WRITE_FUNC
 */
PS_WRITE_FUNC(null)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PS_DESTROY_FUNC
 */
PS_DESTROY_FUNC(null)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PS_GC_FUNC
 */
PS_GC_FUNC(null)
{
	return SUCCESS;
}
/* }}} */

/*
 * Local variables:
 * tab-width: 6
 * c-basic-offset: 6
 * End:
 * vim600: sw=4 ts=4 fdm=marker
 * vim<600: sw=4 ts=4
 */
